@@ -9,7 +9,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(wrap_sub);
 
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 our %SPEC;
 
@@ -329,6 +329,11 @@ sub wrap {
 
     return [304, "Already wrapped"] if Scalar::Util::blessed($sub) && !$force;
 
+    # add properties from convert, if not yet mentioned in meta
+    for (keys %$convert) {
+        $meta->{$_} = undef unless exists $meta->{$_};
+    }
+
     my $v = $meta->{v} // 1.0;
     return [412, "Unsupported metadata version ($v), only 1.1 supported"]
         unless $v == 1.1;
@@ -526,7 +531,7 @@ Perinci::Sub::Wrapper - A multi-purpose subroutine wrapping framework
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
